# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog][],
and this project adheres to [Semantic Versioning][].

[keep a changelog]: https://keepachangelog.com/en/1.0.0/
[semantic versioning]: https://semver.org/spec/v2.0.0.html

## 0.0.2

### Bugfixes
- [Allow generation of empty uns](https://github.com/data-intuitive/dummy-anndata/pull/3)
- [Allow X to be empty](https://github.com/data-intuitive/dummy-anndata/pull/9)

### Improvements
- [Check whether types passed to functions are iterable](https://github.com/data-intuitive/dummy-anndata/pull/4)
- [Remove `generating` prefix](https://github.com/data-intuitive/dummy-anndata/pull/6)
- [Typehint exposed functions](https://github.com/data-intuitive/dummy-anndata/pull/10)


## 0.0.1

### Added

-   Basic generating of datasets possible
